
The NLP pipeline
================

The NLP pipeline consists of five major components: a parser, an
interpreter, a grammar with semantic translations that drives both, an
automated reasoner, and finite-state tools for morphological and phonological 
processing (though the latter are not currently integrated
into the parser). A conversational agent packages up these components
into a test-bed application.

.. toctree::
   :maxdepth: 2
   :titlesonly:

   bot
   grammar/index
   chartparser
   interpreter
   morph
   preproc
   glab
   textgrid

.. toctree::
   :maxdepth: 2
   :titlesonly:
   :caption: Other

   dp/index
